# Contents

Contains examples of using ado with some pre-existing data on performance of
workload configurations in the cloud.

- EXAMPLE_SIMPLE.md - shows performing a random walk
- EXAMPLE_OBJECTIVE.md - shows performing an optimization using a custom
  function defined on the measured performance data
